/**
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
  * http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */

package com.yammer.metrics.reporting

import com.cloudera.kafka.consumer.metrics.ConsumerGroupMetricsHandler
import com.fasterxml.jackson.core.JsonGenerator
import com.yammer.metrics.reporting.CmConsumerGroupMetricsHandler._
import kafka.server.KafkaServer

class CmConsumerGroupMetricsHandler(server: KafkaServer, json: JsonGenerator) extends ConsumerGroupMetricsHandler(server) {

  override def handleGroupCommittedOffset(group: String, topic: String, partition: String, offset: Long): Unit = {
    writeJson(s"$BASE_FIELD_NAME.$GROUP.$group.$PARTITION.$partition.$TOPIC.$topic",
      (COMMITTED_OFFSET, offset))
  }

  private def writeJson(outerFieldName: String, fieldNamesAndValue: (String, Long)): Unit = {
    json.writeFieldName(outerFieldName)

    json.writeStartObject()
    fieldNamesAndValue match { case (innerFieldName, value) =>
      json.writeFieldName(innerFieldName)

      json.writeStartObject()
      json.writeStringField(TYPE, METER)
      json.writeObjectField(COUNT, value)
      json.writeEndObject()
    }
    json.writeEndObject()
  }

}

object CmConsumerGroupMetricsHandler {
  private val BASE_FIELD_NAME = "cloudera.kafka.ConsumerMetrics"
  private val COMMITTED_OFFSET = "CommittedOffset"
  private val PARTITION = "partition"
  private val TOPIC = "topic"
  private val GROUP = "group"
  private val TYPE = "type"
  private val METER = "meter"
  private val COUNT = "count"
}
