/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.techop.kafka

import kafka.server.{BrokerState, KafkaServer, Starting}
import org.junit.Assert.assertTrue
import org.junit.{Before, Test}
import org.mockito.Mockito.{mock, never, verify, when}

class TopicMetricNameResourceErrorTest {
  private var mockBrokerState: BrokerState = _
  private var mockServer: KafkaServer = _
  private var resource: TopicMetricNameResource = _

  @Before
  def setup(): Unit = {
    mockBrokerState = mock(classOf[BrokerState])
    mockServer = mock(classOf[KafkaServer])
    when(mockServer.brokerState).thenReturn(mockBrokerState)

    resource = new TopicMetricNameResource(mockServer)
  }

  @Test
  def testTopicMetricNamesEndpoint(): Unit = {
    when(mockBrokerState.currentState).thenReturn(Starting.state)

    assertTrue(resource.topicNames().topicNames.isEmpty)

    verify(mockServer, never()).zkClient
  }
}
