/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package yammer.metrics.reporting

import java.io.ByteArrayOutputStream

import com.fasterxml.jackson.core.{JsonEncoding, JsonFactory}
import com.yammer.metrics.reporting.CmConsumerGroupMetricsHandler
import org.junit.Assert.assertEquals
import org.junit.Test

class CmConsumerGroupMetricsHandlerTest {

  @Test
  def testHandleGroupCommittedOffset: Unit = {
    testExpected(_.handleGroupCommittedOffset("testGroup", "testTopic", "1", 3332L),
      "{\"cloudera.kafka.ConsumerMetrics.group.testGroup.partition.1.topic.testTopic\":{\"CommittedOffset\":{\"type\":\"meter\",\"count\":3332}}}"
    )
  }

  private def testExpected(execute: CmConsumerGroupMetricsHandler => Unit, expectedJson: String): Unit = {
    val outputStream = new ByteArrayOutputStream
    val generator =  new JsonFactory().createGenerator(outputStream, JsonEncoding.UTF8)
    val cmConsumerMetricHandler = new CmConsumerGroupMetricsHandler(null, generator)
    generator.writeStartObject()
    execute(cmConsumerMetricHandler)
    generator.writeEndObject()
    generator.close()

    assertEquals(outputStream.toString(), expectedJson)
  }

}
